.user-select {
  -moz-user-select: -moz-none;
  -ms-user-select: none;
  -webkit-user-select: none;
  user-select: none; }

*:-moz-placeholder {
  color: #bfbfbf;
  font-style: italic; }
*::-moz-placeholder {
  color: #bfbfbf;
  font-style: italic; }
*:-ms-input-placeholder {
  color: #bfbfbf;
  font-style: italic; }
*::-webkit-input-placeholder {
  color: #bfbfbf;
  font-style: italic; }

input:-moz-placeholder, textarea:-moz-placeholder {
  color: #bfbfbf;
  font-style: italic; }
input::-moz-placeholder, textarea::-moz-placeholder {
  color: #bfbfbf;
  font-style: italic; }
input:-ms-input-placeholder, textarea:-ms-input-placeholder {
  color: #bfbfbf;
  font-style: italic; }
input::-webkit-input-placeholder, textarea::-webkit-input-placeholder {
  color: #bfbfbf;
  font-style: italic; }

.sets-up-browser-support-for-content:-moz-placeholder {
  prefix: -moz;
  -moz-prefix: true;
  -ms-prefix: false;
  -webkit-prefix: false; }
.sets-up-browser-support-for-content::-moz-placeholder {
  prefix: -moz;
  -moz-prefix: true;
  -ms-prefix: false;
  -webkit-prefix: false; }
.sets-up-browser-support-for-content:-ms-input-placeholder {
  prefix: -ms;
  -moz-prefix: false;
  -ms-prefix: true;
  -webkit-prefix: false; }
.sets-up-browser-support-for-content::-webkit-input-placeholder {
  prefix: -webkit;
  -moz-prefix: false;
  -ms-prefix: false;
  -webkit-prefix: true; }
