@import "compass/css3/transition";

.single-transition-without-delay  { @include single-transition(all, 0.6s, ease-out); }
.single-transition-with-delay     { @include single-transition(all, 0.6s, ease-out, 0.2s); }
.transition-duration-list { @include transition-duration((0.2s, 0.5s, 0.2s)); }
.multiple-transition-durations { @include transition-duration(0.2s, 0.5s, 0.2s); }
.single-transform-transition-without-delay  { @include single-transition(transform, 0.6s, ease-out); }
.single-transform-transition-with-delay     { @include single-transition(transform, 0.6s, ease-out, 0.2s); }
.transform-transition { @include transition(transform 0.6s ease-out) }
.multiple-transitions { @include transition(transform 0.6s ease-out, opacity 0.2s ease-in) }
.transition-property { @include transition-property(transform); }
.transition-properties { @include transition-property(transform, opacity, width, height, left, top); }
.multiple-transition-properties { @include transition-property((opacity, transform, left)); }
.default-transition { @include transition(); }
.transition-timing { @include transition-timing-function(ease-in); }
.transition-timings { @include transition-timing-function(ease-in, cubic-bezier(1,0,1,0)); }
.transition-timings-list { @include transition-timing-function((ease-in, cubic-bezier(1,0,1,0))); }
.transition-delay { @include transition-delay(1s); }
.transition-delays { @include transition-delay(1s, 2s, 3s); }
.transition-delays-list { @include transition-delay((1s, 2s, 3s)); }
.regression-912 { @include transition((background-color 0.5s ease-in 0s, width 0.5s ease-out 0s, height 0.5s ease-in 0s, top 0.5s ease-out 0s)); }
