.clear-top-left-corner
  +border-top-left-radius(0)
.clear-top-right-corner
  +border-top-right-radius(0)
.clear-bottom-left-corner
  +border-bottom-left-radius(0)
.clear-bottom-right-corner
  +border-bottom-right-radius(0)

.hide
  display: none
.clear-box-shadow
  +box-shadow(none)
.clear-border-radius
  @extend .clear-rounded-corners
.clear-rounded-corners
  +border-radius(0)
