$project-path: absolute-path(join-file-segments(".."));

@import "compass/configuration";

@function busted($url, $file) {
  @return "busted=true";
}

@function asset-host($path) {
  @return "http://assets#{str-length($path) % 4}.example.com"
}

@include compass-configuration($asset-cache-buster: busted, $asset-host: asset-host);
