.showgrid
  background-image: image-url("grid.png")

.inlinegrid
  background-image: inline-image("grid.png")

.no-buster
  background-image: image-url("grid.png", $only-path: false, $cache-buster: false)

.feed
  background-image: image-url("feed.png")

.dk
  background-image: image-url("flags/dk.png")