ul.horizontal {
  margin: 0;
  padding: 0;
  border: 0;
  overflow: hidden;
  *zoom: 1; }
  ul.horizontal li {
    list-style-image: none;
    list-style-type: none;
    margin-left: 0;
    white-space: nowrap;
    float: left;
    padding-left: 4px;
    padding-right: 4px; }
    ul.horizontal li:first-child {
      padding-left: 0; }
    ul.horizontal li:last-child {
      padding-right: 0; }
    ul.horizontal li.last {
      padding-right: 0; }

ul.wide-horizontal {
  margin: 0;
  padding: 0;
  border: 0;
  overflow: hidden;
  *zoom: 1; }
  ul.wide-horizontal li {
    list-style-image: none;
    list-style-type: none;
    margin-left: 0;
    white-space: nowrap;
    float: left;
    padding-left: 10px;
    padding-right: 10px; }
    ul.wide-horizontal li:first-child {
      padding-left: 0; }
    ul.wide-horizontal li:last-child {
      padding-right: 0; }
    ul.wide-horizontal li.last {
      padding-right: 0; }

ul.right-horizontal {
  margin: 0;
  padding: 0;
  border: 0;
  overflow: hidden;
  *zoom: 1; }
  ul.right-horizontal li {
    list-style-image: none;
    list-style-type: none;
    margin-left: 0;
    white-space: nowrap;
    float: right;
    padding-left: 4px;
    padding-right: 4px; }
    ul.right-horizontal li:first-child {
      padding-right: 0; }
    ul.right-horizontal li:last-child {
      padding-left: 0; }
    ul.right-horizontal li.last {
      padding-left: 0; }

ul.no-padding {
  margin: 0;
  padding: 0;
  border: 0;
  overflow: hidden;
  *zoom: 1; }
  ul.no-padding li {
    list-style-image: none;
    list-style-type: none;
    margin-left: 0;
    white-space: nowrap;
    float: left; }

ul.inline-block {
  margin: 0;
  padding: 0;
  border: 0;
  overflow: hidden;
  *zoom: 1; }
  ul.inline-block li {
    list-style-image: none;
    list-style-type: none;
    margin-left: 0;
    display: inline-block;
    vertical-align: middle;
    *vertical-align: auto;
    *zoom: 1;
    *display: inline;
    white-space: nowrap; }

ul.wide-inline-block {
  margin: 0;
  padding: 0;
  border: 0;
  overflow: hidden;
  *zoom: 1; }
  ul.wide-inline-block li {
    list-style-image: none;
    list-style-type: none;
    margin-left: 0;
    display: inline-block;
    vertical-align: middle;
    *vertical-align: auto;
    *zoom: 1;
    *display: inline;
    white-space: nowrap;
    padding-left: 10px;
    padding-right: 10px; }

ul.inline {
  list-style-type: none; }
  ul.inline, ul.inline li {
    margin: 0;
    padding: 0;
    display: inline; }

ul.comma {
  list-style-type: none; }
  ul.comma, ul.comma li {
    margin: 0;
    padding: 0;
    display: inline; }
  ul.comma li:after {
    content: ", "; }
  ul.comma li:last-child:after {
    content: ""; }
  ul.comma li.last:after {
    content: ""; }

ul.no-bullets {
  list-style: none; }
  ul.no-bullets li {
    list-style-image: none;
    list-style-type: none;
    margin-left: 0; }

ul.pretty {
  margin-left: 0; }
  ul.pretty li {
    padding-left: 14px;
    background: url('/images/4x6.png?busted=true') no-repeat 4px 7px;
    list-style-type: none; }
