.stretched-completely {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0; }

.stretched-horizontally {
  position: absolute;
  left: 0;
  right: 0; }

.stretched-right {
  position: absolute;
  left: 0;
  right: 50%; }

.left-pane {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  right: 50%; }

.stretched-left {
  position: absolute;
  left: 50%;
  right: 0; }

.right-pane {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 50%;
  right: 0; }

.stretched-down {
  position: absolute;
  top: 0;
  bottom: 50%; }

.top-pane {
  position: absolute;
  top: 0;
  bottom: 50%;
  left: 0;
  right: 0; }

.stretched-up {
  position: absolute;
  top: 50%;
  bottom: 0; }

.bottom-pane {
  position: absolute;
  top: 50%;
  bottom: 0;
  left: 0;
  right: 0; }

.viewport {
  position: absolute;
  top: 10px;
  bottom: 30px;
  left: 40px;
  right: 20px; }
