.showgrid { background-image: url('http://assets0.example.com/images/grid-BUSTED.png'); }

.inlinegrid { background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAACgAAAAUEAYAAACv1qP4AAAABmJLR0T///////8JWPfcAAAACXBIWXMAAABIAAAASABGyWs+AAAAZ0lEQVRYw+3QwQ2AIBAFUTEUwI3+uzN7gDscsIgxEuO8An52J11X73OudfxMraXkzHfO3Y98nQEhA0IGhAwIGRAyIGRAyICQASEDQgaEDAgZEDIgZEDIgJABoZzSGK3tPuN9ERFP7Nw4fg+c5g8V1wAAAABJRU5ErkJggg=='); }

.no-buster { background-image: url('http://assets0.example.com/images/grid.png'); }

.feed { background-image: url('http://assets0.example.com/images/feed.png?query_string'); }

.dk { background-image: url('http://assets0.example.com/images/flags/dk.png?query_string'); }

.us { background-image: url('http://assets0.example.com/images/flags/us.png?h=032797efa407ee86590b491e44759b42'); }

.gb { background-image: url('http://assets0.example.com/images/flags/gb.png?i=199110015093513000754718445147053933528'); }
