/* New using px output */
html {
  font-size: 18px;
  line-height: 25px; }

.container {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuNSIgeTE9IjEuMCIgeDI9IjAuNSIgeTI9IjAuMCI+PHN0b3Agb2Zmc2V0PSI1JSIgc3RvcC1jb2xvcj0iIzAwMDAwMCIgc3RvcC1vcGFjaXR5PSIwLjUiLz48c3RvcCBvZmZzZXQ9IjUlIiBzdG9wLWNvbG9yPSIjMDAwMDAwIiBzdG9wLW9wYWNpdHk9IjAuMCIvPjwvbGluZWFyR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
  background-size: 100%;
  background-image: -webkit-gradient(linear, 50% 100%, 50% 0%, color-stop(5%, rgba(0, 0, 0, 0.5)), color-stop(5%, rgba(0, 0, 0, 0)));
  background-image: -moz-linear-gradient(bottom, rgba(0, 0, 0, 0.5) 5%, rgba(0, 0, 0, 0) 5%);
  background-image: -webkit-linear-gradient(bottom, rgba(0, 0, 0, 0.5) 5%, rgba(0, 0, 0, 0) 5%);
  background-image: linear-gradient(to top, rgba(0, 0, 0, 0.5) 5%, rgba(0, 0, 0, 0) 5%);
  -moz-background-size: 100% 25px;
  -o-background-size: 100% 25px;
  -webkit-background-size: 100% 25px;
  background-size: 100% 25px;
  background-position: left top; }

p {
  margin-top: 25px;
  margin-bottom: 25px; }

th,
td {
  padding-top: 6px;
  padding-bottom: 6px; }

/* Incremental leading made easy! */
.caption {
  font-size: 15px;
  line-height: 20px; }

.spaced-out {
  line-height: 37px; }

blockquote {
  margin-top: 25px;
  margin-bottom: 25px;
  padding: 0 25px; }

.fig-quote > blockquote {
  margin-bottom: 12px; }
.fig-quote .source {
  font-size: 15px;
  line-height: 25px;
  margin-bottom: 12px; }

.panel {
  border-width: 1px;
  border-style: solid;
  border-color: #aaaaaa;
  padding: 24px; }
