html.light #demo, html.dark #demo {
  color: #333;
}

#demo {
  @include round-corners;
  @extend .group;
  background: #fff;
  margin-bottom: 1.2em;
  padding: 40px;
  code {
    @include box-shadow(rgba(#000, .3) 0 1px 3px, rgba(#000, .15) 0 1px 0 0 inset);
    background: #fff;
    color: inherit;
  }
}

#how {
  section { width: 49%; float: left; }
  section + section { float: right; }

  .example-source { clear: both; }
}

#reference {
  float: right;
  margin-top: 1em;
}

