@import "project-setup";

.env {
  env: compass-env();  
}

.time {
  time: current-time("%F");
}

.date {
  date: current-date("%F");
}

.filename {
  file: current-source-file();
}

.output {
  output: current-output-file();
}
