/* New using px output */
$base-font-size: 18px;
$base-line-height: $base-font-size * 1.4;
$rhythm-unit: px;
$default-rhythm-border-style: solid #aaaaaa;
@import "compass/typography/vertical_rhythm";

@include establish-baseline;

.container {
	@include debug-vertical-alignment;
}

p {
	@include margin-leader;
	@include margin-trailer;
}

th,
td {
	@include rhythm-padding(.25);
}

/* Incremental leading made easy! */
.caption {
	@include adjust-font-size-to(.85rem, 4/5);
}

.spaced-out {
	@include adjust-leading-to(1.5);
}

blockquote {
	@include rhythm-margins;
	padding: 0 rhythm();
}

.fig-quote {
	> blockquote {
		@include trailer(.5);
	}
	.source {
		@include adjust-font-size-to(.85rem, auto);
		@include trailer(.5);
	}
}

.panel {
	@include rhythm-borders;
}
