@font-face {
  font-family: "font1";
  src: url('/fonts/font1.eot?busted=true');
  src: url('/fonts/font1.eot?&busted=true#iefix') format('embedded-opentype'), url('/fonts/font1.woff?busted=true') format('woff'); }
