@import compass/css3/font-face

+font-face("font1", font-files("font1.woff", woff), "font1.eot")

@font-face
  font-family: 'Issue1491'
  src: font-url('font1.eot')
  src: font-url('font1.eot?#iefix') format('embedded-opentype'), font-url('font1.woff') format('woff')
