.background-origin {
  -moz-background-origin: border;
  -o-background-origin: border-box;
  -webkit-background-origin: border;
  background-origin: border-box; }

.background-origin-multiple {
  -moz-background-origin: border, padding, content;
  -o-background-origin: border-box, padding-box, content-box;
  -webkit-background-origin: border, padding, content;
  background-origin: border-box, padding-box, content-box; }
