.bg-shortcut-simple-image {
  background: white url("foo.png"); }

.bg-shortcut-linear-gradient {
  background: white url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuMCIgeTE9IjAuMCIgeDI9IjEuMCIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2RkZGRkZCIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2FhYWFhYSIvPjwvbGluZWFyR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
  background: white -webkit-gradient(linear, 0% 0%, 100% 100%, color-stop(0%, #dddddd), color-stop(100%, #aaaaaa));
  background: white -moz-linear-gradient(top left, #dddddd, #aaaaaa);
  background: white -webkit-linear-gradient(top left, #dddddd, #aaaaaa);
  background: white linear-gradient(to bottom right, #dddddd, #aaaaaa); }

.bg-linear-gradient-angle-svg {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjEuMCIgeTE9IjEuMCIgeDI9IjAuMCIgeTI9IjAuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iIzAwMDBmZiIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iIzAwMDAwMCIvPjwvbGluZWFyR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
  background-size: 100%;
  background-image: -moz-linear-gradient(135deg, #0000ff, #000000);
  background-image: -webkit-linear-gradient(135deg, #0000ff, #000000);
  background-image: linear-gradient(-45deg, #0000ff, #000000); }

.bg-linear-gradient-angle2-svg {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuMCIgeTE9IjAuMCIgeDI9IjEuMCIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iIzAwMDBmZiIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iIzAwMDAwMCIvPjwvbGluZWFyR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
  background-size: 100%;
  background-image: -webkit-gradient(linear, 0% 0%, 100% 100%, color-stop(0%, #0000ff), color-stop(100%, #000000));
  background-image: -moz-linear-gradient(top left, #0000ff, #000000);
  background-image: -webkit-linear-gradient(top left, #0000ff, #000000);
  background-image: linear-gradient(to bottom right, #0000ff, #000000); }

.bg-simple-image {
  background-image: url("foo.png"); }

.bg-linear-gradient {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuMCIgeTE9IjAuMCIgeDI9IjEuMCIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2RkZGRkZCIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2FhYWFhYSIvPjwvbGluZWFyR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
  background-size: 100%;
  background-image: -webkit-gradient(linear, 0% 0%, 100% 100%, color-stop(0%, #dddddd), color-stop(100%, #aaaaaa));
  background-image: -moz-linear-gradient(top left, #dddddd, #aaaaaa);
  background-image: -webkit-linear-gradient(top left, #dddddd, #aaaaaa);
  background-image: linear-gradient(to bottom right, #dddddd, #aaaaaa); }

.bg-linear-gradient-pixel-stop-from-top {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuNSIgeTE9IjAuMCIgeDI9IjAuNSIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIyNSUiIHN0b3AtY29sb3I9IiNkZGRkZGQiLz48c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29sb3I9IiNhYWFhYWEiLz48L2xpbmVhckdyYWRpZW50PjwvZGVmcz48cmVjdCB4PSIwIiB5PSIwIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiBmaWxsPSJ1cmwoI2dyYWQpIiAvPjwvc3ZnPiA=');
  background-size: 100%;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 40, color-stop(25%, #dddddd), color-stop(100%, #aaaaaa));
  background-image: -moz-linear-gradient(top, #dddddd 10px, #aaaaaa 40px);
  background-image: -webkit-linear-gradient(top, #dddddd 10px, #aaaaaa 40px);
  background-image: linear-gradient(to bottom, #dddddd 10px, #aaaaaa 40px); }

.bg-linear-gradient-pixel-stop-from-left {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuMCIgeTE9IjAuNSIgeDI9IjEuMCIgeTI9IjAuNSI+PHN0b3Agb2Zmc2V0PSIyNSUiIHN0b3AtY29sb3I9IiNkZGRkZGQiLz48c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29sb3I9IiNhYWFhYWEiLz48L2xpbmVhckdyYWRpZW50PjwvZGVmcz48cmVjdCB4PSIwIiB5PSIwIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiBmaWxsPSJ1cmwoI2dyYWQpIiAvPjwvc3ZnPiA=');
  background-size: 100%;
  background-image: -webkit-gradient(linear, 0% 50%, 40 50%, color-stop(25%, #dddddd), color-stop(100%, #aaaaaa));
  background-image: -moz-linear-gradient(left, #dddddd 10px, #aaaaaa 40px);
  background-image: -webkit-linear-gradient(left, #dddddd 10px, #aaaaaa 40px);
  background-image: linear-gradient(to right, #dddddd 10px, #aaaaaa 40px); }

.transparent-in-linear-gradient {
  background-image: white url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuMCIgeTE9IjAuMCIgeDI9IjEuMCIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iIzAwMDAwMCIgc3RvcC1vcGFjaXR5PSIwLjAiLz48c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29sb3I9IiNhYWFhYWEiLz48L2xpbmVhckdyYWRpZW50PjwvZGVmcz48cmVjdCB4PSIwIiB5PSIwIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiBmaWxsPSJ1cmwoI2dyYWQpIiAvPjwvc3ZnPiA=');
  background-size: 100%;
  background-image: white -webkit-gradient(linear, 0% 0%, 100% 100%, color-stop(0%, rgba(0, 0, 0, 0)), color-stop(100%, #aaaaaa));
  background-image: white -moz-linear-gradient(top left, rgba(0, 0, 0, 0), #aaaaaa);
  background-image: white -webkit-linear-gradient(top left, rgba(0, 0, 0, 0), #aaaaaa);
  background-image: white linear-gradient(to bottom right, rgba(0, 0, 0, 0), #aaaaaa); }

.currentColor-in-linear-gradient {
  background-image: white url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuMCIgeTE9IjAuMCIgeDI9IjEuMCIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iIzAwMDAwMCIgc3RvcC1vcGFjaXR5PSIwLjAiLz48c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29sb3I9ImN1cnJlbnRDb2xvciIvPjwvbGluZWFyR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
  background-size: 100%;
  background-image: white -webkit-gradient(linear, 0% 0%, 100% 100%, color-stop(0%, rgba(0, 0, 0, 0)), color-stop(100%, currentColor));
  background-image: white -moz-linear-gradient(top left, rgba(0, 0, 0, 0), currentColor);
  background-image: white -webkit-linear-gradient(top left, rgba(0, 0, 0, 0), currentColor);
  background-image: white linear-gradient(to bottom right, rgba(0, 0, 0, 0), currentColor); }

.calc-in-linear-gradient {
  background-image: -moz-linear-gradient(left, #ffffff calc(100% - 50px), rgba(0, 0, 0, 0) calc(100% - 50px));
  background-image: -webkit-linear-gradient(left, #ffffff calc(100% - 50px), rgba(0, 0, 0, 0) calc(100% - 50px));
  background-image: linear-gradient(to right, #ffffff calc(100% - 50px), rgba(0, 0, 0, 0) calc(100% - 50px)); }

.rgba-in-linear-gradient {
  background-image: white url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuMCIgeTE9IjAuMCIgeDI9IjEuMCIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2ZmZmZmZiIgc3RvcC1vcGFjaXR5PSIwLjgiLz48c3RvcCBvZmZzZXQ9IjEwMCUiIHN0b3AtY29sb3I9IiMwMDAwMDAiIHN0b3Atb3BhY2l0eT0iMC4xIi8+PC9saW5lYXJHcmFkaWVudD48L2RlZnM+PHJlY3QgeD0iMCIgeT0iMCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgZmlsbD0idXJsKCNncmFkKSIgLz48L3N2Zz4g');
  background-size: 100%;
  background-image: white -webkit-gradient(linear, 0% 0%, 100% 100%, color-stop(0%, rgba(255, 255, 255, 0.8)), color-stop(100%, rgba(0, 0, 0, 0.1)));
  background-image: white -moz-linear-gradient(top left, rgba(255, 255, 255, 0.8), rgba(0, 0, 0, 0.1));
  background-image: white -webkit-linear-gradient(top left, rgba(255, 255, 255, 0.8), rgba(0, 0, 0, 0.1));
  background-image: white linear-gradient(to bottom right, rgba(255, 255, 255, 0.8), rgba(0, 0, 0, 0.1)); }

.bg-shortcut-radial-gradient {
  background: white url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PHJhZGlhbEdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgY3g9IjUwJSIgY3k9IjUwJSIgcj0iMTAwJSI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2RkZGRkZCIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2FhYWFhYSIvPjwvcmFkaWFsR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
  background: white -moz-radial-gradient(center center, #dddddd, #aaaaaa 100px);
  background: white -webkit-radial-gradient(center center, #dddddd, #aaaaaa 100px);
  background: white radial-gradient(center center, #dddddd, #aaaaaa 100px); }

.bg-all-gradient-types-with-simplification {
  background: #ffcc00;
  background: url('/images/4x6.png?busted=true'), url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuMCIgeTE9IjAuMCIgeDI9IjEuMCIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2RkZGRkZCIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2FhYWFhYSIvPjwvbGluZWFyR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA=='), url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PHJhZGlhbEdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgY3g9IjUwJSIgY3k9IjUwJSIgcj0iMTAwJSI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2RkZGRkZCIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2FhYWFhYSIvPjwvcmFkaWFsR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA=='), #ffcc00;
  background: url('/images/4x6.png?busted=true'), -webkit-gradient(linear, 0% 0%, 100% 100%, color-stop(0%, #dddddd), color-stop(100%, #aaaaaa)), radial-gradient(center center, #dddddd, #aaaaaa 100px), #ffcc00;
  background: url('/images/4x6.png?busted=true'), -moz-linear-gradient(top left, #dddddd, #aaaaaa), -moz-radial-gradient(center center, #dddddd, #aaaaaa 100px), #ffcc00;
  background: url('/images/4x6.png?busted=true'), -webkit-linear-gradient(top left, #dddddd, #aaaaaa), -webkit-radial-gradient(center center, #dddddd, #aaaaaa 100px), #ffcc00;
  background: url('/images/4x6.png?busted=true'), linear-gradient(to bottom right, #dddddd, #aaaaaa), radial-gradient(center center, #dddddd, #aaaaaa 100px), #ffcc00; }

.bg-radial-gradient {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PHJhZGlhbEdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgY3g9IjUwJSIgY3k9IjUwJSIgcj0iMTAwJSI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2RkZGRkZCIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iIzAwMDAwMCIgc3RvcC1vcGFjaXR5PSIwLjAiLz48L3JhZGlhbEdyYWRpZW50PjwvZGVmcz48cmVjdCB4PSIwIiB5PSIwIiB3aWR0aD0iMTAwJSIgaGVpZ2h0PSIxMDAlIiBmaWxsPSJ1cmwoI2dyYWQpIiAvPjwvc3ZnPiA=');
  background-size: 100%;
  background-image: -moz-radial-gradient(center center, #dddddd, rgba(0, 0, 0, 0) 100px);
  background-image: -webkit-radial-gradient(center center, #dddddd, rgba(0, 0, 0, 0) 100px);
  background-image: radial-gradient(center center, #dddddd, rgba(0, 0, 0, 0) 100px); }

.currentColor-in-radial-gradient {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PHJhZGlhbEdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgY3g9IjUwJSIgY3k9IjUwJSIgcj0iMTAwJSI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iY3VycmVudENvbG9yIi8+PHN0b3Agb2Zmc2V0PSIxMDAlIiBzdG9wLWNvbG9yPSIjMDAwMDAwIiBzdG9wLW9wYWNpdHk9IjAuMCIvPjwvcmFkaWFsR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
  background-size: 100%;
  background-image: -moz-radial-gradient(center center, currentColor, rgba(0, 0, 0, 0) 100px);
  background-image: -webkit-radial-gradient(center center, currentColor, rgba(0, 0, 0, 0) 100px);
  background-image: radial-gradient(center center, currentColor, rgba(0, 0, 0, 0) 100px); }

.bg-linear-gradient-with-angle {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjEuMCIgeTE9IjEuMCIgeDI9IjAuMCIgeTI9IjAuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2RkZGRkZCIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2FhYWFhYSIvPjwvbGluZWFyR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
  background-size: 100%;
  background-image: -moz-linear-gradient(135deg, #dddddd, #aaaaaa);
  background-image: -webkit-linear-gradient(135deg, #dddddd, #aaaaaa);
  background-image: linear-gradient(-45deg, #dddddd, #aaaaaa); }

.bg-radial-gradient-with-angle-and-shape {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PHJhZGlhbEdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgY3g9ImVsbGlwc2UiIGN5PSJjb3ZlciIgcj0iMTAwJSI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2RkZGRkZCIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2FhYWFhYSIvPjwvcmFkaWFsR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
  background-size: 100%;
  background-image: -moz-radial-gradient(ellipse cover, #dddddd, #aaaaaa 100px);
  background-image: -webkit-radial-gradient(ellipse cover, #dddddd, #aaaaaa 100px);
  background-image: radial-gradient(ellipse cover, #dddddd, #aaaaaa 100px); }

.bg-all-gradient-types {
  background-image: url('/images/4x6.png?busted=true'), url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuMCIgeTE9IjAuMCIgeDI9IjEuMCIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2RkZGRkZCIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2FhYWFhYSIvPjwvbGluZWFyR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA=='), url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PHJhZGlhbEdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgY3g9IjUwJSIgY3k9IjUwJSIgcj0iMTAwJSI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2RkZGRkZCIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2FhYWFhYSIvPjwvcmFkaWFsR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
  background-size: 100%;
  background-image: url('/images/4x6.png?busted=true'), -webkit-gradient(linear, 0% 0%, 100% 100%, color-stop(0%, #dddddd), color-stop(100%, #aaaaaa)), radial-gradient(center center, #dddddd, #aaaaaa 100px);
  background-image: url('/images/4x6.png?busted=true'), -moz-linear-gradient(top left, #dddddd, #aaaaaa), -moz-radial-gradient(center center, #dddddd, #aaaaaa 100px);
  background-image: url('/images/4x6.png?busted=true'), -webkit-linear-gradient(top left, #dddddd, #aaaaaa), -webkit-radial-gradient(center center, #dddddd, #aaaaaa 100px);
  background-image: url('/images/4x6.png?busted=true'), linear-gradient(to bottom right, #dddddd, #aaaaaa), radial-gradient(center center, #dddddd, #aaaaaa 100px); }

.border-image-gradient {
  -moz-border-image: -moz-radial-gradient(#00ff00, #ff0000 100px) 100 stretch;
  -moz-border-image: radial-gradient(#00ff00, #ff0000 100px) 100 stretch;
  -o-border-image: radial-gradient(#00ff00, #ff0000 100px) 100 stretch;
  -webkit-border-image: -webkit-radial-gradient(#00ff00, #ff0000 100px) 100 stretch;
  -webkit-border-image: radial-gradient(#00ff00, #ff0000 100px) 100 stretch;
  border-image: -moz-radial-gradient(#00ff00, #ff0000 100px) 100 stretch;
  border-image: -webkit-radial-gradient(#00ff00, #ff0000 100px) 100 stretch;
  border-image: radial-gradient(#00ff00, #ff0000 100px) 100 stretch; }

.direct-list-image-plain {
  list-style-image: url('/images/4x6.png?busted=true'); }

.shorthand-list-image-plain {
  list-style: outside url('/images/4x6.png?busted=true'); }

.direct-list-image-with-gradient {
  list-style-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PHJhZGlhbEdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgY3g9IjUwJSIgY3k9IjUwJSIgcj0iMTAlIj48c3RvcCBvZmZzZXQ9IjAlIiBzdG9wLWNvbG9yPSIjMDBmZjAwIi8+PHN0b3Agb2Zmc2V0PSIxMDAlIiBzdG9wLWNvbG9yPSIjZmYwMDAwIi8+PC9yYWRpYWxHcmFkaWVudD48L2RlZnM+PHJlY3QgeD0iMCIgeT0iMCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgZmlsbD0idXJsKCNncmFkKSIgLz48L3N2Zz4g');
  list-style-image: -moz-radial-gradient(#00ff00, #ff0000 10px);
  list-style-image: -webkit-radial-gradient(#00ff00, #ff0000 10px);
  list-style-image: radial-gradient(#00ff00, #ff0000 10px); }

.shorthand-list-image-with-gradient {
  list-style: outside url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PHJhZGlhbEdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgY3g9IjUwJSIgY3k9IjUwJSIgcj0iMTAlIj48c3RvcCBvZmZzZXQ9IjAlIiBzdG9wLWNvbG9yPSIjMDBmZjAwIi8+PHN0b3Agb2Zmc2V0PSIxMDAlIiBzdG9wLWNvbG9yPSIjZmYwMDAwIi8+PC9yYWRpYWxHcmFkaWVudD48L2RlZnM+PHJlY3QgeD0iMCIgeT0iMCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgZmlsbD0idXJsKCNncmFkKSIgLz48L3N2Zz4g');
  list-style: outside -moz-radial-gradient(#00ff00, #ff0000 10px);
  list-style: outside -webkit-radial-gradient(#00ff00, #ff0000 10px);
  list-style: outside radial-gradient(#00ff00, #ff0000 10px); }

.content-plain {
  content: "asdf"; }

.content-with-gradient {
  content: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PHJhZGlhbEdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJ1c2VyU3BhY2VPblVzZSIgY3g9IjUwJSIgY3k9IjUwJSIgcj0iMTAlIj48c3RvcCBvZmZzZXQ9IjAlIiBzdG9wLWNvbG9yPSIjMDBmZjAwIi8+PHN0b3Agb2Zmc2V0PSIxMDAlIiBzdG9wLWNvbG9yPSIjZmYwMDAwIi8+PC9yYWRpYWxHcmFkaWVudD48L2RlZnM+PHJlY3QgeD0iMCIgeT0iMCIgd2lkdGg9IjEwMCUiIGhlaWdodD0iMTAwJSIgZmlsbD0idXJsKCNncmFkKSIgLz48L3N2Zz4g');
  content: -moz-radial-gradient(#00ff00, #ff0000 10px);
  content: -webkit-radial-gradient(#00ff00, #ff0000 10px);
  content: radial-gradient(#00ff00, #ff0000 10px); }

.bg-linear-gradient-no-position {
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #dddddd), color-stop(100%, #aaaaaa));
  background-image: -moz-linear-gradient(#dddddd, #aaaaaa);
  background-image: -webkit-linear-gradient(#dddddd, #aaaaaa);
  background-image: linear-gradient(#dddddd, #aaaaaa); }

.bg-radial-gradient-no-position {
  background-image: -moz-radial-gradient(#dddddd, #aaaaaa 100px);
  background-image: -webkit-radial-gradient(#dddddd, #aaaaaa 100px);
  background-image: radial-gradient(#dddddd, #aaaaaa 100px); }

.image-fallback {
  background-image: image(-moz-radial-gradient(#dddddd, #aaaaaa 100px), url('/images/4x6.png?busted=true'), #cc0000);
  background-image: -webkit-image(-webkit-radial-gradient(#dddddd, #aaaaaa 100px), url('/images/4x6.png?busted=true'), #cc0000);
  background-image: image(radial-gradient(#dddddd, #aaaaaa 100px), url('/images/4x6.png?busted=true'), #cc0000); }

.cross-fade {
  background-image: cross-fade(-moz-radial-gradient(#dddddd, #aaaaaa 100px), url('/images/4x6.png?busted=true'));
  background-image: -webkit-cross-fade(-webkit-radial-gradient(#dddddd, #aaaaaa 100px), url('/images/4x6.png?busted=true'));
  background-image: cross-fade(radial-gradient(#dddddd, #aaaaaa 100px), url('/images/4x6.png?busted=true')); }

.unknown-function-wrapper {
  background: foo(-moz-radial-gradient(#dddddd, #aaaaaa 100px));
  background: foo(-webkit-radial-gradient(#dddddd, #aaaaaa 100px));
  background: foo(radial-gradient(#dddddd, #aaaaaa 100px)); }

.ie-horizontal-filter {
  *zoom: 1;
  filter: progid:DXImageTransform.Microsoft.gradient(gradientType=1, startColorstr='#FFFFFFFF', endColorstr='#FF000000'); }

.ie-vertical-filter {
  *zoom: 1;
  filter: progid:DXImageTransform.Microsoft.gradient(gradientType=0, startColorstr='#FFFFFFFF', endColorstr='#FF000000'); }

.ie-alpha-filter {
  *zoom: 1;
  filter: progid:DXImageTransform.Microsoft.gradient(gradientType=0, startColorstr='#FFFFFFFF', endColorstr='#00FFFFFF'); }

.linear-gradient-new {
  background: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ff0000), color-stop(100%, #88aa44));
  background: -moz-linear-gradient(top, #ff0000 0%, #88aa44 100%);
  background: -webkit-linear-gradient(top, #ff0000 0%, #88aa44 100%);
  background: linear-gradient(to bottom, #ff0000 0%, #88aa44 100%); }

.radial-gradient-old {
  /* radial-gradient(yellow, green) */
  background: -moz-radial-gradient(#ffff00, #008000);
  background: -webkit-radial-gradient(#ffff00, #008000);
  background: radial-gradient(#ffff00, #008000);
  /* radial-gradient(ellipse at center, yellow 0%, green 100%) */
  background: -moz-radial-gradient(center, ellipse, #ffff00 0%, #008000 100%);
  background: -webkit-radial-gradient(center, ellipse, #ffff00 0%, #008000 100%);
  background: radial-gradient(ellipse at center, #ffff00 0%, #008000 100%);
  /* radial-gradient(farthest-corner at 50% 50%, yellow, green) */
  background: -moz-radial-gradient(50% 50%, farthest-corner, #ffff00, #008000);
  background: -webkit-radial-gradient(50% 50%, farthest-corner, #ffff00, #008000);
  background: radial-gradient(farthest-corner at 50% 50%, #ffff00, #008000);
  /* radial-gradient(circle, yellow, green) */
  background: -moz-radial-gradient(circle, #ffff00, #008000);
  background: -webkit-radial-gradient(circle, #ffff00, #008000);
  background: radial-gradient(circle, #ffff00, #008000);
  /* radial-gradient(red, yellow, green) */
  background: -moz-radial-gradient(#ff0000, #ffff00, #008000);
  background: -webkit-radial-gradient(#ff0000, #ffff00, #008000);
  background: radial-gradient(#ff0000, #ffff00, #008000);
  /* radial-gradient(farthest-side at left bottom, red, yellow 50px, green) */
  background: -moz-radial-gradient(left bottom, farthest-side, #ff0000, #ffff00 50px, #008000);
  background: -webkit-radial-gradient(left bottom, farthest-side, #ff0000, #ffff00 50px, #008000);
  background: radial-gradient(farthest-side at left bottom, #ff0000, #ffff00 50px, #008000);
  /* radial-gradient(closest-side at 20px 30px, red, yellow, green) */
  background: -moz-radial-gradient(20px 30px, closest-side, #ff0000, #ffff00, #008000);
  background: -webkit-radial-gradient(20px 30px, closest-side, #ff0000, #ffff00, #008000);
  background: radial-gradient(closest-side at 20px 30px, #ff0000, #ffff00, #008000);
  /* radial-gradient(20px 30px at 40px 50px, red, yellow, green) */
  background: -moz-radial-gradient(40px 50px, 20px 30px, #ff0000, #ffff00, #008000);
  background: -webkit-radial-gradient(40px 50px, 20px 30px, #ff0000, #ffff00, #008000);
  background: radial-gradient(20px 30px at 40px 50px, #ff0000, #ffff00, #008000);
  /* radial-gradient(closest-side circle at , red, yellow, green) */
  background: -moz-radial-gradient(20px 30px, closest-side circle, #ff0000, #ffff00, #008000);
  background: -webkit-radial-gradient(20px 30px, closest-side circle, #ff0000, #ffff00, #008000);
  background: radial-gradient(closest-side circle at 20px 30px, #ff0000, #ffff00, #008000);
  /* radial-gradient(20px 20px at 20px 30px, red, yellow, green) */
  background: -moz-radial-gradient(20px 30px, 20px 20px, #ff0000, #ffff00, #008000);
  background: -webkit-radial-gradient(20px 30px, 20px 20px, #ff0000, #ffff00, #008000);
  background: radial-gradient(20px 20px at 20px 30px, #ff0000, #ffff00, #008000); }

.radial-gradient-new {
  /* radial-gradient(yellow, green) */
  background: -moz-radial-gradient(#ffff00, #008000);
  background: -webkit-radial-gradient(#ffff00, #008000);
  background: radial-gradient(#ffff00, #008000);
  /* radial-gradient(ellipse at center, yellow 0%, green 100%) */
  background: -moz-radial-gradient(center, ellipse, #ffff00 0%, #008000 100%);
  background: -webkit-radial-gradient(center, ellipse, #ffff00 0%, #008000 100%);
  background: radial-gradient(ellipse at center, #ffff00 0%, #008000 100%);
  /* radial-gradient(farthest-corner at 50% 50%, yellow, green) */
  background: -moz-radial-gradient(50% 50%, farthest-corner, #ffff00, #008000);
  background: -webkit-radial-gradient(50% 50%, farthest-corner, #ffff00, #008000);
  background: radial-gradient(farthest-corner at 50% 50%, #ffff00, #008000);
  /* radial-gradient(circle, yellow, green) */
  background: -moz-radial-gradient(circle, #ffff00, #008000);
  background: -webkit-radial-gradient(circle, #ffff00, #008000);
  background: radial-gradient(circle, #ffff00, #008000);
  /* radial-gradient(red, yellow, green) */
  background: -moz-radial-gradient(#ff0000, #ffff00, #008000);
  background: -webkit-radial-gradient(#ff0000, #ffff00, #008000);
  background: radial-gradient(#ff0000, #ffff00, #008000);
  /* radial-gradient(farthest-side at left bottom, red, yellow 50px, green) */
  background: -moz-radial-gradient(left bottom, farthest-side, #ff0000, #ffff00 50px, #008000);
  background: -webkit-radial-gradient(left bottom, farthest-side, #ff0000, #ffff00 50px, #008000);
  background: radial-gradient(farthest-side at left bottom, #ff0000, #ffff00 50px, #008000);
  /* radial-gradient(closest-side at 20px 30px, red, yellow, green) */
  background: -moz-radial-gradient(20px 30px, closest-side, #ff0000, #ffff00, #008000);
  background: -webkit-radial-gradient(20px 30px, closest-side, #ff0000, #ffff00, #008000);
  background: radial-gradient(closest-side at 20px 30px, #ff0000, #ffff00, #008000);
  /* radial-gradient(20px 30px at 20px 30px, red, yellow, green) */
  background: -moz-radial-gradient(40px 50px, 20px 30px, #ff0000, #ffff00, #008000);
  background: -webkit-radial-gradient(40px 50px, 20px 30px, #ff0000, #ffff00, #008000);
  background: radial-gradient(20px 30px at 40px 50px, #ff0000, #ffff00, #008000);
  /* radial-gradient(closest-side circle at 20px 30px, red, yellow, green) */
  background: -moz-radial-gradient(20px 30px, closest-side circle, #ff0000, #ffff00, #008000);
  background: -webkit-radial-gradient(20px 30px, closest-side circle, #ff0000, #ffff00, #008000);
  background: radial-gradient(closest-side circle at 20px 30px, #ff0000, #ffff00, #008000);
  /* radial-gradient(20px 20px at 20px 30px, red, yellow, green) */
  background: -moz-radial-gradient(30px 30px, 20px 20px, #ff0000, #ffff00, #008000);
  background: -webkit-radial-gradient(30px 30px, 20px 20px, #ff0000, #ffff00, #008000);
  background: radial-gradient(20px 20px at 30px 30px, #ff0000, #ffff00, #008000); }

.linear-gradient-old {
  background: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #ff0000), color-stop(100%, #88aa44));
  background: -moz-linear-gradient(top, #ff0000 0%, #88aa44 100%);
  background: -webkit-linear-gradient(top, #ff0000 0%, #88aa44 100%);
  background: linear-gradient(to bottom, #ff0000 0%, #88aa44 100%); }

.linear-gradient-unknown-new {
  background: -moz-linear-gradient(330deg, #ff0000 0%, #88aa44 100%);
  background: -webkit-linear-gradient(330deg, #ff0000 0%, #88aa44 100%);
  background: linear-gradient(120deg, #ff0000 0%, #88aa44 100%); }

.linear-gradient-unknown-old {
  background: -moz-linear-gradient(120deg, #ff0000 0%, #88aa44 100%);
  background: -webkit-linear-gradient(120deg, #ff0000 0%, #88aa44 100%);
  background: linear-gradient(330deg, #ff0000 0%, #88aa44 100%); }

.issue-1676-has-svg-because-of-minimums {
  background-image: url('data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4gPHN2ZyB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+PGRlZnM+PGxpbmVhckdyYWRpZW50IGlkPSJncmFkIiBncmFkaWVudFVuaXRzPSJvYmplY3RCb3VuZGluZ0JveCIgeDE9IjAuNSIgeTE9IjAuMCIgeDI9IjAuNSIgeTI9IjEuMCI+PHN0b3Agb2Zmc2V0PSIwJSIgc3RvcC1jb2xvcj0iI2RkZGRkZCIvPjxzdG9wIG9mZnNldD0iMTAwJSIgc3RvcC1jb2xvcj0iI2FhYWFhYSIvPjwvbGluZWFyR3JhZGllbnQ+PC9kZWZzPjxyZWN0IHg9IjAiIHk9IjAiIHdpZHRoPSIxMDAlIiBoZWlnaHQ9IjEwMCUiIGZpbGw9InVybCgjZ3JhZCkiIC8+PC9zdmc+IA==');
  background-size: 100%;
  background-image: -webkit-gradient(linear, 50% 0%, 50% 100%, color-stop(0%, #dddddd), color-stop(100%, #aaaaaa));
  background-image: -moz-linear-gradient(#dddddd, #aaaaaa);
  background-image: -webkit-linear-gradient(#dddddd, #aaaaaa);
  background-image: linear-gradient(#dddddd, #aaaaaa); }

.issue-1766 {
  background: radial-gradient(#ffffff, #000000);
  background: linear-gradient(#ffffff, #000000); }
