// Regions

@import "compass/support";

// The prefixed support threshold for css regions.
// Defaults to the $graceful-usage-threshold.
$regions-support-threshold: $graceful-usage-threshold !default;


// Webkit, IE10 and future support for [CSS Regions](http://dev.w3.org/csswg/css3-regions/)
//
// $target is a value you use to link two regions of your css.
// Give the source of your content the flow-into property,
// and give your target container the flow-from property.
//
// For a visual explanation, see the diagrams at Chris Coyier's
// [CSS-Tricks](http://css-tricks.com/content-folding/)

@mixin flow-into($target) {
  $target: unquote($target);
  @include prefixed-properties(css-regions, $regions-support-threshold, (flow-into: $target));
}

@mixin flow-from($target) {
  $target: unquote($target);
  @include prefixed-properties(css-regions, $regions-support-threshold, (flow-from: $target));
}
