@import "compass/css3";

.example {
  padding: 2em;
  div {
    background: {
      image: image-url("examples/css3/bg-origin/bg.png");
      repeat: repeat;
      position: top left;
    };
    border: 10px solid rgba(255, 0, 0, 0.5);
    color: white;
    @include text-shadow(darken(blue, 50%) 2px 2px);
    padding: 1em;
    text-align: center;
    margin-bottom: 2em;
  }
  #padding-box {
    @include background-origin(padding-box);
  }
  #border-box {
    @include background-origin(border-box);
  }
  #content-box {
    @include background-origin(content-box);
  }
}
