@import "compass/css3";

.example {
  padding: 2em;
  div {
    background: {
      image: image-url("examples/css3/bg-origin/bg.png");
      repeat: no-repeat;
      position: top left;
    };
    border: 10px solid rgba(255, 0, 0, 0.5);
    color: black;
    @include text-shadow(white 1px 1px 4px);
    padding: 1em;
    text-align: center;
    margin-bottom: 2em;
  }
  #auto {
    @include background-size(auto);
  }
  #contain {
    @include background-size(contain);
  }
  #cover {
    @include background-size(cover);
  }
  #percent {
    @include background-size(50% 50%);
  }
  #absolute {
    @include background-size(100px 25px);
  }
}
