.background-size-default {
  -moz-background-size: 100% auto;
  -o-background-size: 100% auto;
  -webkit-background-size: 100% auto;
  background-size: 100% auto; }

.background-size-single {
  -moz-background-size: 50% 25%;
  -o-background-size: 50% 25%;
  -webkit-background-size: 50% 25%;
  background-size: 50% 25%; }

.background-size-multiple {
  -moz-background-size: 4em 3em, 100% auto, 50%;
  -o-background-size: 4em 3em, 100% auto, 50%;
  -webkit-background-size: 4em 3em, 100% auto, 50%;
  background-size: 4em 3em, 100% auto, 50%; }
