@import project-setup
.png
  width: image_width(unquote("100x150.png"))
  height: image_height(unquote("100x150.png"))

.jpg
  width: image_width(unquote("100x150.jpg"))
  height: image_height(unquote("100x150.jpg"))

.jpeg
  width: image_width(unquote("100x150.jpeg"))
  height: image_height(unquote("100x150.jpeg"))

.gif
  width: image_width(unquote("100x150.gif"))
  height: image_height(unquote("100x150.gif"))
