.handles-null {
  content: "there should be no property below this one"; }

.contrasts-light {
  background-color: #eeeeee;
  color: black; }

.contrasts-dark {
  background-color: #222222;
  color: white; }

.contrasts-light-with-contrast-color-override {
  background-color: #eeeeee;
  color: red; }

.contrasts-dark-with-contrast-color-override {
  background-color: #222222;
  color: yellow; }
