$blueprint_grid_columns: 3;

@import "blueprint/grid.scss";

#one {
  @include column(2, true);
  @include prepend(1);
  background-color: #11770e;
}

#two {
  @include column(1);
  @include pull(3, true);
  background-color: #242677;
}
