@import "compass";
@import "compass/layout";
@import "core/extensions";

@include global-reset;
@include reset-html5;

@import "core/base-classes";
@import "core/media-block";

@import "partials/theme";
@import "partials/layout";
@import "partials/typography";

@import "partials/nav";
@import "partials/sidebar";
@import "partials/ads";
@import "partials/main";
@import "partials/code";
@import "partials/example";
@import "partials/install";
@import "partials/blog";

@import "syntax/syntax-theme";

@import "core/clearing-classes";


html.dark { @include dark-theme(true); }
html.light { @include light-theme(true); }

footer {
  margin: 0 auto;
  width: 640px;
}

blockquote {
  @extend code;
}

#page h3 {
  padding-left: 0;
}
