@import "project-setup";
.relative {
  background-image: image-url("4x6.png");
}
.root-relative {
  background-image: image-url("/images/4x6.png");
}
.absolute {
  background-image: image-url("http://example.com/images/4x6.png");
}
