@import "compass/utilities/color/brightness";

.black-is-0-percent {
  brightness: brightness(black); }
.white-is-100-percent {
  brightness: brightness(white); }
.green-is-58-point-7-percent {
  brightness: brightness(#00ff00); }
.blue-is-11-point-4-percent {
  brightness: brightness(#0000ff); }
.red-is-29-point-9-percent {
  brightness: brightness(#ff0000); }
