.showgrid
  font-family: font-url("grid.ttf", $only-path: false, $cache-buster: true)

.no-buster
  font-family: font-url("grid.ttf", $only-path: false, $cache-buster: false)

.buster-by-default
  font-family: font-url("grid.ttf")

.feed
  font-family: font-url("feed.ttf", $only-path: false, $cache-buster: true)

.dk
  font-family: font-url("sub/dk.ttf", $only-path: false, $cache-buster: true)
