@import "project-setup";
@import "compass/css3/user-interface";

.user-select {
  @include user-select(none);
}

* {
  @include input-placeholder {
    color: #bfbfbf;
    font-style: italic;
  }
}

#{elements-of-type(text-input)} {
  @include input-placeholder {
    color: #bfbfbf;
    font-style: italic;
  }
}

.sets-up-browser-support-for-content {
  @include input-placeholder {
    prefix: $current-prefix;
    -moz-prefix: $current-prefix == -moz;
    -ms-prefix: $current-prefix == -ms;
    -webkit-prefix: $current-prefix == -webkit;
  }
}
