.single-transition-without-delay {
  -moz-transition: all 0.6s ease-out;
  -o-transition: all 0.6s ease-out;
  -webkit-transition: all 0.6s ease-out;
  transition: all 0.6s ease-out; }

.single-transition-with-delay {
  -moz-transition: all 0.6s ease-out 0.2s;
  -o-transition: all 0.6s ease-out 0.2s;
  -webkit-transition: all 0.6s ease-out;
  -webkit-transition-delay: 0.2s;
  transition: all 0.6s ease-out 0.2s; }

.transition-duration-list {
  -moz-transition-duration: 0.2s, 0.5s, 0.2s;
  -o-transition-duration: 0.2s, 0.5s, 0.2s;
  -webkit-transition-duration: 0.2s, 0.5s, 0.2s;
  transition-duration: 0.2s, 0.5s, 0.2s; }

.multiple-transition-durations {
  -moz-transition-duration: 0.2s, 0.5s, 0.2s;
  -o-transition-duration: 0.2s, 0.5s, 0.2s;
  -webkit-transition-duration: 0.2s, 0.5s, 0.2s;
  transition-duration: 0.2s, 0.5s, 0.2s; }

.single-transform-transition-without-delay {
  -moz-transition: -moz-transform 0.6s ease-out;
  -o-transition: -o-transform 0.6s ease-out;
  -webkit-transition: -webkit-transform 0.6s ease-out;
  transition: transform 0.6s ease-out; }

.single-transform-transition-with-delay {
  -moz-transition: -moz-transform 0.6s ease-out 0.2s;
  -o-transition: -o-transform 0.6s ease-out 0.2s;
  -webkit-transition: -webkit-transform 0.6s ease-out;
  -webkit-transition-delay: 0.2s;
  transition: transform 0.6s ease-out 0.2s; }

.transform-transition {
  -moz-transition: -moz-transform 0.6s ease-out;
  -o-transition: -o-transform 0.6s ease-out;
  -webkit-transition: -webkit-transform 0.6s ease-out;
  transition: transform 0.6s ease-out; }

.multiple-transitions {
  -moz-transition: -moz-transform 0.6s ease-out, opacity 0.2s ease-in;
  -o-transition: -o-transform 0.6s ease-out, opacity 0.2s ease-in;
  -webkit-transition: -webkit-transform 0.6s ease-out, opacity 0.2s ease-in;
  transition: transform 0.6s ease-out, opacity 0.2s ease-in; }

.transition-property {
  -moz-transition-property: -moz-transform;
  -o-transition-property: -o-transform;
  -webkit-transition-property: -webkit-transform;
  transition-property: transform; }

.transition-properties {
  -moz-transition-property: -moz-transform, opacity, width, height, left, top;
  -o-transition-property: -o-transform, opacity, width, height, left, top;
  -webkit-transition-property: -webkit-transform, opacity, width, height, left, top;
  transition-property: transform, opacity, width, height, left, top; }

.multiple-transition-properties {
  -moz-transition-property: opacity, -moz-transform, left;
  -o-transition-property: opacity, -o-transform, left;
  -webkit-transition-property: opacity, -webkit-transform, left;
  transition-property: opacity, transform, left; }

.default-transition {
  -moz-transition: all 1s;
  -o-transition: all 1s;
  -webkit-transition: all 1s;
  transition: all 1s; }

.transition-timing {
  -moz-transition-timing-function: ease-in;
  -o-transition-timing-function: ease-in;
  -webkit-transition-timing-function: ease-in;
  transition-timing-function: ease-in; }

.transition-timings {
  -moz-transition-timing-function: ease-in, cubic-bezier(1, 0, 1, 0);
  -o-transition-timing-function: ease-in, cubic-bezier(1, 0, 1, 0);
  -webkit-transition-timing-function: ease-in, cubic-bezier(1, 0, 1, 0);
  transition-timing-function: ease-in, cubic-bezier(1, 0, 1, 0); }

.transition-timings-list {
  -moz-transition-timing-function: ease-in, cubic-bezier(1, 0, 1, 0);
  -o-transition-timing-function: ease-in, cubic-bezier(1, 0, 1, 0);
  -webkit-transition-timing-function: ease-in, cubic-bezier(1, 0, 1, 0);
  transition-timing-function: ease-in, cubic-bezier(1, 0, 1, 0); }

.transition-delay {
  -moz-transition-delay: 1s;
  -o-transition-delay: 1s;
  -webkit-transition-delay: 1s;
  transition-delay: 1s; }

.transition-delays {
  -moz-transition-delay: 1s, 2s, 3s;
  -o-transition-delay: 1s, 2s, 3s;
  -webkit-transition-delay: 1s, 2s, 3s;
  transition-delay: 1s, 2s, 3s; }

.transition-delays-list {
  -moz-transition-delay: 1s, 2s, 3s;
  -o-transition-delay: 1s, 2s, 3s;
  -webkit-transition-delay: 1s, 2s, 3s;
  transition-delay: 1s, 2s, 3s; }

.regression-912 {
  -moz-transition: background-color 0.5s ease-in 0s, width 0.5s ease-out 0s, height 0.5s ease-in 0s, top 0.5s ease-out 0s;
  -o-transition: background-color 0.5s ease-in 0s, width 0.5s ease-out 0s, height 0.5s ease-in 0s, top 0.5s ease-out 0s;
  -webkit-transition: background-color 0.5s ease-in, width 0.5s ease-out, height 0.5s ease-in, top 0.5s ease-out;
  -webkit-transition-delay: 0s, 0s, 0s, 0s;
  transition: background-color 0.5s ease-in 0s, width 0.5s ease-out 0s, height 0.5s ease-in 0s, top 0.5s ease-out 0s; }
