@font-face {
  font-family: "pictos-web";
  src: url('/otherfonts/pictos-web.eot');
  src: local("?"), url('/otherfonts/pictos-web.woff') format('woff'), url('/otherfonts/pictos-web.ttf') format('truetype'), url('/otherfonts/pictos-web.svg#webfontIyfZbseF') format('svg');}

@include font-face("museosans-web", font-files("museosans-web.woff", woff, "museosans-web.ttf", truetype, "museosans-web.svg#webfontJHBEijmD", svg), 'museosans-web.eot');


.sans-font { font-family: 'Lucida Grande', Arial, sans-serif; }
.heading-font { font-family: 'Museo Sans', "museosans-web", 'serif'; }
.pictos { font-family: pictos, pictos-web; font-weight: normal; font-style: normal;}
.fixed-font { font-family: menlo, monaco, "andale mono", "courier new", fixed;}

#page {
  line-height: 1.45em;
  ol { list-style: outside decimal; padding-left: 2.5em; }
  ol ol { list-style: outside lower-alpha; padding-left: 2.5em; }
  ul, ol, dl { margin-bottom: 1.5em;}
  p { margin-bottom: 1.2em;}
  #{headings(1,2)}{ @extend .heading-font; line-height: 1.2em; }
  h1 { font-size: 35px; margin-bottom: 15px; padding-bottom: 6px; }
  h2 { font-size: 26px; margin: 1em 0 15px; padding-bottom: 6px; }
  h3 { font-size: 18px; }
  h4 { font-size: 18px; margin: .4em 0; }
  ul { list-style: inside disc; }
  dt { font-weight: bold; }
}
#page aside {
  ul { list-style: none; margin-bottom: 1em;}
  h2 { line-height: 1.3em; margin-top: 0; padding-top: 3px;}
}
em     { font-style: italic; }
strong { font-weight: bold;  }

#page > article {
  ul ul { padding-left: 1em; }
  position: relative;
  h2 { font-size: 26px; margin: .5em 0 .6em;
    padding: 1em 0 6px;}
  hr + h2 { padding-top: 0; }
  hr + h3, h4, h5 { margin-top: 0; }
}

dl.table dt, dl.table dd { display: inline-block; }
dg { display: block; margin-bottom: 1.5em; }

.warning { color: #c00; }