.example {
  #{enumerate(".class", 2, 4)} {
    background-color: #aaaaaa;
    border: 2px solid #777777;
    margin: 1em;
  }
  @for $i from 2 through 4 {
    .class-#{$i} {
      margin-left: 1em * ($i - 1);
    }
  }
}
