.advertisement {
  padding: 8px 5px !important;
  text-align: center;
  line-height: 1.1em !important;
  @include opacity(0);
  @include transition(opacity 1s ease-in 1.5s);
  &.visible {
    @include opacity(1);
  }
  a:not(.pagerankspam) {
    display: block;
    color: white;
    @extend .heading-font;
    text-decoration: none;
    &:hover {
      @include text-shadow(0 0 2px #aaa);
    }
  }
  .pagerankspam { font-size: 9px; }
 .dark & {
   @extend .code-block-dark;
   img:hover { @include single-box-shadow($color: white); }
 }
 .light & {
   @extend .code-block-light;
   a:not(.pagerankspam) { color: #222}
   img:hover { @include single-box-shadow($color: #222); }
 }
 #home & {
   float: right;
   width: 380px;
   margin-top: 11px;
   .fusionimg {
     margin: 6px 8px;
     float: left;
   }
   .fusiontext {
     padding-top: 6px;
   }
 }
}

