$min-width: 700px;
$side-nav-width: 160px;
$main-min-width: $min-width - $side-nav-width;

body {
  max-width: 1500px;
  min-width: $min-width;
  margin: 0 auto;
  @extend .sans-font;
  line-height: 1.45em;
}

#wrap { @extend .group; padding: 0 20px 20px; }
#page { @extend .group; padding-bottom: 30px; }
footer { @extend .group; clear: both; padding-top: 20px;}
header { padding: 22px 0 0; position: relative; }
#page aside + article { margin-left: $side-nav-width + 22px; padding-left: 23px; }
aside { float: left; width: $side-nav-width; position: relative; z-index: 2;}

body#home #page article { padding-left: 0;}
body.site, body#changelog, body.default { max-width: 1024px; }
