.android {
  versions: "2.1", "2.2", "2.3", "3", "4", "4.1", "4.2-4.3", "4.4", "4.4.3";
  background-img-opts: -webkit;
  background-img-opts-unprefixed-at: "3";
  border-image: -webkit;
  border-image-unprefixed-at: "4.4";
  border-radius: -webkit;
  border-radius-unprefixed-at: "2.2";
  css-animation: -webkit;
  css-appearance: -webkit;
  css-boxshadow: -webkit;
  css-boxshadow-unprefixed-at: "4";
  css-canvas: -webkit;
  css-filters: -webkit;
  css-gradients: -webkit;
  css-gradients-unprefixed-at: "4.4";
  css-masks: -webkit;
  css-placeholder: -webkit;
  css-reflections: -webkit;
  css-repeating-gradients: -webkit;
  css-repeating-gradients-unprefixed-at: "4.4";
  css-transitions: -webkit;
  css-transitions-unprefixed-at: "4.4";
  css3-boxsizing: -webkit;
  css3-boxsizing-unprefixed-at: "4";
  font-feature: -webkit;
  intrinsic-width: -webkit;
  multicolumn: -webkit;
  text-stroke: -webkit;
  transforms2d: -webkit;
  transforms3d: -webkit;
  user-select-none: -webkit; }

.android-chrome {
  versions: "36";
  css-animation: -webkit;
  css-appearance: -webkit;
  css-canvas: -webkit;
  css-filters: -webkit;
  css-masks: -webkit;
  css-placeholder: -webkit;
  css-reflections: -webkit;
  font-feature: -webkit;
  intrinsic-width: -webkit;
  multicolumn: -webkit;
  text-stroke: -webkit;
  transforms3d: -webkit;
  user-select-none: -webkit; }

.android-firefox {
  versions: "31";
  css-appearance: -moz;
  css-hyphens: -moz;
  css-placeholder: -moz;
  css3-tabsize: -moz;
  font-feature: -moz;
  intrinsic-width: -moz;
  multicolumn: -moz;
  text-decoration: -moz;
  text-size-adjust: -moz;
  user-select-none: -moz; }

.blackberry {
  versions: "7", "10";
  border-image: -webkit;
  border-image-unprefixed-at: "10";
  calc: -webkit;
  css-animation: -webkit;
  css-appearance: -webkit;
  css-boxshadow: -webkit;
  css-boxshadow-unprefixed-at: "10";
  css-canvas: -webkit;
  css-filters: -webkit;
  css-gradients: -webkit;
  css-masks: -webkit;
  css-placeholder: -webkit;
  css-reflections: -webkit;
  css-repeating-gradients: -webkit;
  css-transitions: -webkit;
  css3-boxsizing: -webkit;
  css3-boxsizing-unprefixed-at: "10";
  flexbox: -webkit;
  font-feature: -webkit;
  intrinsic-width: -webkit;
  multicolumn: -webkit;
  text-stroke: -webkit;
  transforms2d: -webkit;
  transforms3d: -webkit;
  user-select-none: -webkit; }

.chrome {
  versions: "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", "36", "37", "38", "39";
  border-image: -webkit;
  border-image-unprefixed-at: "16";
  border-radius: -webkit;
  border-radius-unprefixed-at: "5";
  calc: -webkit;
  calc-unprefixed-at: "26";
  css-animation: -webkit;
  css-appearance: -webkit;
  css-boxshadow: -webkit;
  css-boxshadow-unprefixed-at: "10";
  css-canvas: -webkit;
  css-filters: -webkit;
  css-gradients: -webkit;
  css-gradients-unprefixed-at: "26";
  css-masks: -webkit;
  css-placeholder: -webkit;
  css-reflections: -webkit;
  css-regions: -webkit;
  css-regions-unprefixed-at: "19";
  css-repeating-gradients: -webkit;
  css-repeating-gradients-unprefixed-at: "26";
  css-transitions: -webkit;
  css-transitions-unprefixed-at: "26";
  css3-boxsizing: -webkit;
  css3-boxsizing-unprefixed-at: "10";
  flexbox: -webkit;
  flexbox-unprefixed-at: "29";
  font-feature: -webkit;
  intrinsic-width: -webkit;
  multicolumn: -webkit;
  text-stroke: -webkit;
  transforms2d: -webkit;
  transforms2d-unprefixed-at: "36";
  transforms3d: -webkit;
  transforms3d-unprefixed-at: "36";
  user-select-none: -webkit; }

.firefox {
  versions: "2", "3", "3.5", "3.6", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", "32", "33", "34";
  background-img-opts: -moz;
  background-img-opts-unprefixed-at: "4";
  border-image: -moz;
  border-image-unprefixed-at: "15";
  border-radius: -moz;
  border-radius-unprefixed-at: "4";
  calc: -moz;
  calc-unprefixed-at: "16";
  css-animation: -moz;
  css-animation-unprefixed-at: "16";
  css-appearance: -moz;
  css-boxshadow: -moz;
  css-boxshadow-unprefixed-at: "4";
  css-gradients: -moz;
  css-gradients-unprefixed-at: "16";
  css-hyphens: -moz;
  css-placeholder: -moz;
  css-repeating-gradients: -moz;
  css-repeating-gradients-unprefixed-at: "16";
  css-resize: prefix-no-longer-needed;
  css-resize-unprefixed-at: "5";
  css-selection: -moz;
  css-transitions: -moz;
  css-transitions-unprefixed-at: "16";
  css3-boxsizing: -moz;
  css3-boxsizing-unprefixed-at: "29";
  css3-tabsize: -moz;
  font-feature: -moz;
  font-feature-unprefixed-at: "32";
  inline-block: prefix-no-longer-needed;
  inline-block-unprefixed-at: "3";
  intrinsic-width: -moz;
  multicolumn: -moz;
  text-decoration: -moz;
  transforms2d: -moz;
  transforms2d-unprefixed-at: "16";
  transforms3d: -moz;
  transforms3d-unprefixed-at: "16";
  user-select-none: -moz; }

.ie {
  versions: "5.5", "6", "7", "8", "9", "10", "11";
  css-grid: -ms;
  css-hyphens: -ms;
  css-placeholder: -ms;
  css-regions: -ms;
  transforms2d: -ms;
  transforms2d-unprefixed-at: "10";
  user-select-none: -ms; }

.ie-mobile {
  versions: "10";
  css-grid: -ms;
  css-placeholder: -ms;
  css-regions: -ms;
  text-size-adjust: -ms;
  user-select-none: -ms; }

.ios-safari {
  versions: "3.2", "4.0-4.1", "4.2-4.3", "5.0-5.1", "6.0-6.1", "7.0-7.1", "8";
  border-image: -webkit;
  border-image-unprefixed-at: "6.0-6.1";
  border-radius: -webkit;
  border-radius-unprefixed-at: "4.0-4.1";
  calc: -webkit;
  calc-unprefixed-at: "7.0-7.1";
  css-animation: -webkit;
  css-appearance: -webkit;
  css-boxshadow: -webkit;
  css-boxshadow-unprefixed-at: "5.0-5.1";
  css-canvas: -webkit;
  css-filters: -webkit;
  css-gradients: -webkit;
  css-gradients-unprefixed-at: "7.0-7.1";
  css-hyphens: -webkit;
  css-masks: -webkit;
  css-placeholder: -webkit;
  css-reflections: -webkit;
  css-regions: -webkit;
  css-repeating-gradients: -webkit;
  css-repeating-gradients-unprefixed-at: "7.0-7.1";
  css-shapes: prefix-no-longer-needed;
  css-sticky: -webkit;
  css-transitions: -webkit;
  css-transitions-unprefixed-at: "7.0-7.1";
  css3-boxsizing: -webkit;
  css3-boxsizing-unprefixed-at: "5.0-5.1";
  flexbox: -webkit;
  intrinsic-width: -webkit;
  multicolumn: -webkit;
  text-size-adjust: -webkit;
  text-stroke: -webkit;
  transforms2d: -webkit;
  transforms3d: -webkit;
  user-select-none: -webkit; }

.opera {
  versions: "9.5-9.6", "10.0-10.1", "10.5", "10.6", "11", "11.1", "11.5", "11.6", "12", "12.1", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24";
  background-img-opts: -webkit;
  background-img-opts-unprefixed-at: "10.5";
  border-image: -webkit;
  border-image-unprefixed-at: "15";
  css-animation: -webkit;
  css-appearance: -webkit;
  css-canvas: -webkit;
  css-filters: -webkit;
  css-gradients: -webkit;
  css-gradients-unprefixed-at: "12.1";
  css-masks: -webkit;
  css-placeholder: -webkit;
  css-reflections: -webkit;
  css-repeating-gradients: -webkit;
  css-repeating-gradients-unprefixed-at: "12.1";
  css-transitions: -webkit;
  css-transitions-unprefixed-at: "12.1";
  css3-tabsize: prefix-no-longer-needed;
  css3-tabsize-unprefixed-at: "15";
  flexbox: -webkit;
  flexbox-unprefixed-at: "17";
  font-feature: -webkit;
  intrinsic-width: -webkit;
  multicolumn: -webkit;
  object-fit: prefix-no-longer-needed;
  object-fit-unprefixed-at: "15";
  text-overflow: prefix-no-longer-needed;
  text-overflow-unprefixed-at: "11";
  text-stroke: -webkit;
  transforms2d: -webkit;
  transforms2d-unprefixed-at: "23";
  transforms3d: -webkit;
  transforms3d-unprefixed-at: "23";
  user-select-none: -webkit; }

.opera-mini {
  versions: "5.0-7.0";
  text-overflow: -o; }

.opera-mobile {
  versions: "10", "11.5", "12", "12.1", "22";
  border-image: -o;
  border-image-unprefixed-at: "22";
  css-animation: prefix-no-longer-needed;
  css-appearance: prefix-no-longer-needed;
  css-canvas: prefix-no-longer-needed;
  css-filters: prefix-no-longer-needed;
  css-gradients: prefix-no-longer-needed;
  css-gradients-unprefixed-at: "12.1";
  css-masks: prefix-no-longer-needed;
  css-placeholder: prefix-no-longer-needed;
  css-reflections: prefix-no-longer-needed;
  css-repeating-gradients: prefix-no-longer-needed;
  css-repeating-gradients-unprefixed-at: "12.1";
  css-transitions: -o;
  css-transitions-unprefixed-at: "12.1";
  css3-tabsize: -o;
  css3-tabsize-unprefixed-at: "22";
  font-feature: prefix-no-longer-needed;
  intrinsic-width: prefix-no-longer-needed;
  multicolumn: prefix-no-longer-needed;
  object-fit: -o;
  object-fit-unprefixed-at: "22";
  text-overflow: -o;
  text-overflow-unprefixed-at: "12.1";
  text-stroke: prefix-no-longer-needed;
  transforms2d: prefix-no-longer-needed;
  transforms3d: prefix-no-longer-needed;
  user-select-none: prefix-no-longer-needed; }

.safari {
  versions: "3.1", "3.2", "4", "5", "5.1", "6", "6.1", "7", "8";
  border-image: -webkit;
  border-image-unprefixed-at: "6";
  border-radius: -webkit;
  border-radius-unprefixed-at: "5";
  calc: -webkit;
  calc-unprefixed-at: "6.1";
  css-animation: -webkit;
  css-appearance: -webkit;
  css-boxshadow: -webkit;
  css-boxshadow-unprefixed-at: "5.1";
  css-canvas: -webkit;
  css-filters: -webkit;
  css-gradients: -webkit;
  css-gradients-unprefixed-at: "6.1";
  css-hyphens: -webkit;
  css-masks: -webkit;
  css-placeholder: -webkit;
  css-reflections: -webkit;
  css-regions: -webkit;
  css-repeating-gradients: -webkit;
  css-repeating-gradients-unprefixed-at: "6.1";
  css-shapes: prefix-no-longer-needed;
  css-sticky: -webkit;
  css-transitions: -webkit;
  css-transitions-unprefixed-at: "6.1";
  css3-boxsizing: -webkit;
  css3-boxsizing-unprefixed-at: "5.1";
  flexbox: -webkit;
  intrinsic-width: -webkit;
  multicolumn: -webkit;
  text-stroke: -webkit;
  transforms2d: -webkit;
  transforms3d: -webkit;
  user-select-none: -webkit; }
