@import "compass/css3";

.box-shadow-example div {
  width: 40px;
  height: 40px;
  background: #eeeeee;
  margin: 20px;
  float: left;
}

// Default single box shadow
#box-shadow-default {
  @include single-box-shadow;
}

// Box shadow with custom settings
#box-shadow-custom {
  @include box-shadow(red 2px 2px 10px);
}

#box-shadow-custom-multiple {
  @include box-shadow(rgba(blue, 0.4) 0 0 25px, rgba(green, 0.2) 0 0 3px 1px inset);
}
