$default-rounded-corner: 4

.group
  +pie-clearfix

.truncate
  +ellipsis

.border-box
  +box-sizing(border-box)

.round-corners-4
  +border-radius(4px)

.round-corners-em
  +border-radius(1em)
  
=round-corners($num: $default-rounded-corner)
  @extend .round-corners-#{$num}

=round-top-corners($num: $default-rounded-corner)
  +round-corners($num)
  @extend .clear-bottom-right-corner
  @extend .clear-bottom-left-corner
=round-bottom-corners($num: $default-rounded-corner)
  +round-corners($num)
  @extend .clear-top-right-corner
  @extend .clear-top-left-corner
=round-left-corners($num: $default-rounded-corner)
  +round-corners($num)
  @extend .clear-top-right-corner
  @extend .clear-bottom-right-corner
=round-right-corners($num: $default-rounded-corner)
  +round-corners($num)
  @extend .clear-top-left-corner
  @extend .clear-bottom-left-corner

=round-top-left-corner($num: $default-rounded-corner)
  +round-corners($num)
  @extend .clear-top-right-corner
  @extend .clear-bottom-right-corner
  @extend .clear-bottom-left-corner
=round-top-right-corner($num: $default-rounded-corner)
  +round-corners($num)
  @extend .clear-top-left-corner
  @extend .clear-bottom-right-corner
  @extend .clear-bottom-left-corner
=round-bottom-left-corner($num: $default-rounded-corner)
  +round-corners($num)
  @extend .clear-top-right-corner
  @extend .clear-bottom-right-corner
  @extend .clear-top-left-corner
=round-bottom-right-corner($num: $default-rounded-corner)
  +round-corners($num)
  @extend .clear-top-right-corner
  @extend .clear-top-left-corner
  @extend .clear-bottom-left-corner

=square-top-left-corner($num: $default-rounded-corner)
  +round-corners($num)
  @extend .clear-top-left-corner
=square-top-right-corner($num: $default-rounded-corner)
  +round-corners($num)
  @extend .clear-top-right-corner
=square-bottom-left-corner($num: $default-rounded-corner)
  +round-corners($num)
  @extend .clear-bottom-left-corner
=square-bottom-right-corner($num: $default-rounded-corner)
  +round-corners($num)
  @extend .clear-bottom-right-corner