/* line 1, ../sass/partials/_1.scss */
.one {
  value: 1;
}

/* line 1, ../sass/partials/_2.scss */
.two {
  value: 2;
}

/* line 1, ../sass/partials/_3.scss */
.three {
  value: 3;
}

/* line 3, ../sass/screen.scss */
.something {
  awww: yeah;
}
