.black-is-0-percent {
  brightness: 0%; }

.white-is-100-percent {
  brightness: 100%; }

.green-is-58-point-7-percent {
  brightness: 58.7%; }

.blue-is-11-point-4-percent {
  brightness: 11.4%; }

.red-is-29-point-9-percent {
  brightness: 29.9%; }
