html, body {
  height: 100%; }

#layout {
  clear: both;
  min-height: 100%;
  height: auto !important;
  height: 100%;
  margin-bottom: -72px; }
  #layout #layout_footer {
    height: 72px; }

#footer {
  clear: both;
  position: relative;
  height: 72px; }
