// Since you've installed the xml file, you should set
// $use-mozilla-ellipsis-binding to true before importing.
$use-mozilla-ellipsis-binding: true
@import compass/typography/text/ellipsis

// You can delete this sass file if you want, it's just an example of how to use the ellipsis mixin.
// By default, ellipsis text is no-wrap. Pass false as the first argument if you don't want that.
.ellipsis
  +ellipsis