@import "project-setup";
@import "compass/typography/lists";

ul.horizontal        { @include horizontal-list;             }
ul.wide-horizontal   { @include horizontal-list(10px);       }
ul.right-horizontal  { @include horizontal-list(4px, right); }
ul.no-padding        { @include horizontal-list(false);      }
ul.inline-block      { @include inline-block-list;           }
ul.wide-inline-block { @include inline-block-list(10px);     }
ul.inline            { @include inline-list;                 }
ul.comma             { @include delimited-list;              }
ul.no-bullets        { @include no-bullets;                  }
ul.pretty            { @include pretty-bullets("4x6.png");   }
