@import "project-setup";
@import "compass/css3/background-clip";

.background-clip { @include background-clip('border-box'); }

.background-clip-multiple { @include background-clip('border-box', padding-box, content-box); }
