@import "compass";
@import "core/extensions";
@include reset(global);
@include reset(html5);
@import "core/base-classes";
@import "core/media-block";

@import "partials/theme";
@import "partials/layout";
@import "partials/nav";
@import "partials/typography";
@import "partials/main";
@import "partials/code";
@import "partials/home";
@import "partials/ads";

html.dark { @include dark-theme; }
html.light { @include light-theme; }

@import "core/clearing-classes";
