.no-box-shadow {
  -moz-box-shadow: none;
  -webkit-box-shadow: none;
  box-shadow: none; }

.box-shadow {
  -moz-box-shadow: 0px 0px 5px #333333, 2px 2px 5px #222222;
  -webkit-box-shadow: 0px 0px 5px #333333, 2px 2px 5px #222222;
  box-shadow: 0px 0px 5px #333333, 2px 2px 5px #222222; }

.single-box-shadow {
  -moz-box-shadow: 0px 5px #333333;
  -webkit-box-shadow: 0px 5px #333333;
  box-shadow: 0px 5px #333333; }

.multiple-box-shadows {
  -moz-box-shadow: 0px 0px 5px #333333, 2px 2px 5px #222222;
  -webkit-box-shadow: 0px 0px 5px #333333, 2px 2px 5px #222222;
  box-shadow: 0px 0px 5px #333333, 2px 2px 5px #222222; }

.legacy-single-box-shadow {
  -moz-box-shadow: 0px 5px blue;
  -webkit-box-shadow: 0px 5px blue;
  box-shadow: 0px 5px blue; }
