$project-path: absolute-path(join-file-segments(".."));

@import "compass/configuration";

@function busted($url, $file) {
  @return "busted=true";
}

@include compass-configuration($asset-cache-buster: busted);

