.showgrid { font-family: url('http://assets3.example.com/fonts/grid-BUSTED.ttf'); }

.no-buster { font-family: url('http://assets3.example.com/fonts/grid.ttf'); }

.buster-by-default { font-family: url('http://assets3.example.com/fonts/grid-BUSTED.ttf'); }

.feed { font-family: url('http://assets3.example.com/fonts/feed.ttf?query_string'); }

.dk { font-family: url('http://assets1.example.com/fonts/sub/dk.ttf?query_string'); }
