@import "project-setup";
@import "compass/css3/animation";

@include keyframes(test) {
  0%, 100% {
    background-color: red; }
  50% {
    background-color: blue;
  }
}

.animation {
  @include animation(test);
}
