@import "compass/typography/text/replacement";
.basic {
  @include replace-text("4x6.png");
}
.with-dimensions {
  @include replace-text-with-dimensions("4x6.png");
}
.with-dimensions-inline {
  @include replace-text-with-dimensions("4x6.png", $inline: true);
}
.with-position {
  @include replace-text("4x6.png", 10px, top);
}
.with-arbitrary-url {
  @include replace-text(url(http://google.com/logo.gif), 10px, top);
}
.with-inline-url {
  @include replace-text(inline-image("4x6.png"), 10px, top);
}
.with-image-url {
  @include replace-text(image-url("4x6.png"), 10px, top);
}
