.env {
  env: <%= options[:environment] %>; }
.time {
  time: <%= Time.now.strftime("%F") %>; }
.date {
  date: <%= Time.now.strftime("%F") %>; }
.filename {
  file: env.scss; }
.output {
  output: env.css; }
