.simple {
  -moz-border-radius: 4px / 4px;
  -webkit-border-radius: 4px 4px;
  border-radius: 4px / 4px; }

.compound {
  -moz-border-radius: 2px 5px / 3px 6px;
  -webkit-border-radius: 2px 3px;
  border-radius: 2px 5px / 3px 6px; }

.crazy {
  -moz-border-radius: 1px 3px 5px 7px / 2px 4px 6px 8px;
  -webkit-border-radius: 1px 2px;
  border-radius: 1px 3px 5px 7px / 2px 4px 6px 8px; }
