.display {
  display: -webkit-flex;
  display: flex; }

.flex-direction {
  -webkit-flex-direction: row-reverse;
  flex-direction: row-reverse; }

.flex-wrap {
  -webkit-flex-wrap: wrap-reverse;
  flex-wrap: wrap-reverse; }

.flex-flow {
  -webkit-flex-flow: row-reverse wrap-reverse;
  flex-flow: row-reverse wrap-reverse; }

.order {
  -webkit-order: 1;
  order: 1; }

.flex {
  -webkit-flex: 1 0 auto;
  flex: 1 0 auto; }

.flex-grow {
  -webkit-flex-grow: 1;
  flex-grow: 1; }

.flex-shrink {
  -webkit-flex-shrink: 1;
  flex-shrink: 1; }

.flex-basis {
  -webkit-flex-basis: auto;
  flex-basis: auto; }

.justify-content {
  -webkit-justify-content: flex-start;
  justify-content: flex-start; }

.align-items {
  -webkit-align-items: flex-start;
  align-items: flex-start; }

.align-self {
  -webkit-align-self: flex-start;
  align-self: flex-start; }

.align-content {
  -webkit-align-content: flex-start;
  align-content: flex-start; }

.flexbox {
  display: -webkit-flex;
  -webkit-flex-direction: row-reverse;
  -webkit-flex-wrap: wrap-reverse;
  -webkit-flex-flow: row-reverse wrap-reverse;
  -webkit-order: 1;
  -webkit-flex: 1 0 auto;
  -webkit-flex-grow: 1;
  -webkit-flex-shrink: 0;
  -webkit-flex-basis: auto;
  -webkit-justify-content: flex-start;
  -webkit-align-items: flex-start;
  -webkit-align-self: flex-start;
  -webkit-align-content: flex-start;
  display: flex;
  flex-direction: row-reverse;
  flex-wrap: wrap-reverse;
  flex-flow: row-reverse wrap-reverse;
  order: 1;
  flex: 1 0 auto;
  flex-grow: 1;
  flex-shrink: 0;
  flex-basis: auto;
  justify-content: flex-start;
  align-items: flex-start;
  align-self: flex-start;
  align-content: flex-start; }

.flexbox-2 {
  display: -ms-flexbox;
  -ms-flex-flow: row-reverse;
  -ms-flex-order: 1; }

.flexbox-1 {
  display: -moz-box;
  -moz-box-orient: vertical;
  -moz-box-ordinal-group: 1;
  -moz-box-flex: 1;
  display: -webkit-box;
  -webkit-box-orient: vertical;
  -webkit-box-ordinal-group: 1;
  -webkit-box-flex: 1; }
