body.get-involved h1 + p { font-size: 1.2em; line-height: 1.45em; }

#page {
  position: relative;
  padding-top: 40px;
  & > article { padding-top: 10px; font-size: 15px;
  img { max-width: 100%; } } }

#theme_pref {
  a { display: block; font-size: 18px; width: .9em; position: relative; text-decoration: none; @extend .pictos; } }

#docs_panel {
  position: absolute; top: 0; right: 0;
  width: 100%;
  & > div { float: right; margin-left: 10px; @include round-bottom-corners; border: 1px solid; border-top: 0;}
  a { text-decoration: none; }
  #theme_pref { padding: 3px 12px 6px; a { position: relative; top: 2px;} }
  #version { font-size: .75em; padding: 4px 0 5px; background: none; border: none; position: absolute; left: 0; a { @include hover-link; } }

}

#syntax_pref, .syntax_pref { padding: 4px 8px 5px; a { font-size: .9em; padding: 0px 6px 1px; display: inline-block; line-height: 1.45em;} }

.syntax_pref {
  float: left; @include round-top-corners; border: 1px solid; border-bottom: 0;
  a { text-decoration: none; }
}

footer {
  .links { float: left; font-size: .9em;
    img { vertical-align: middle; padding-right: 5px; position: relative; top: -2px;}
    span { position: relative; top: -1px; }
    ul { @include horizontal-list(15px); overflow: visible;
    li { padding-top: 3px; }
    li:last-child {border: 0; @include box-shadow(none); } } }
}
#page article h2 {
  margin-top: 1.5em;
}
h2 a.help {
  text-indent: -9999px;
  display: inline-block;
  position: relative;
  text-decoration: none;
  @include opacity(.3);
  &:hover { @include opacity(.7); }
  &:before {
    @extend .pictos;
    content: "?";
    text-indent: 0;
    position: absolute;
    top: 2px;
    left: 0;
    font-size: .85em;
  }
}
hr {
  height: 0px;
  border: 0;
  border-bottom-width: 4px;
  margin: 3em 0;
  background: transparent;
}
