@import "compass/utilities/tables/alternating-rows-and-columns";

.example {
  table {
    $table-color: #7a98c6;
    @include alternating-rows-and-columns($table-color, adjust-hue($table-color, -120deg), #222222);
  }
}
