.showgrid
  background-image: image-url(unquote("grid.png"))

.inlinegrid
  background-image: inline-image(unquote("grid.png"))

.no-buster
  background-image: image-url("grid.png", $only-path: false, $cache-buster: false)
