aside {
  padding-top: 15px;
  text-align: right;
  padding-right: 22px;
  h2, h3 {
    text-align: left;
    font-size: 1.3em;
    line-height: 1.45em;
    padding-bottom: .2em;
    margin-bottom: .4em;
    @extend .clear-border-radius;
  }
  h3 {
    padding: 0 0 .5em; line-height: 1.1em;
  }
  a {
    font-size: .85em;
  }
  ul ul a {
    &.selected, &.selected:hover {
      font-weight: bold;
      text-decoration: underline;
    }
  }
  .deprecated {
    text-decoration: line-through;
  }
  .beta span:after {
    content: " (\3B2)";
  }
}
